==> knative-model-4.9.2-sources.jar: io/fabric8/knative/serving/v1/ServiceSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface ServiceSpecFluent<A extends ServiceSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public RevisionTemplateSpec getTemplate();
    public RevisionTemplateSpec buildTemplate();
    public A withTemplate(RevisionTemplateSpec template);
    public Boolean hasTemplate();
    public ServiceSpecFluent.TemplateNested<A> withNewTemplate();
    public ServiceSpecFluent.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item);
    public ServiceSpecFluent.TemplateNested<A> editTemplate();
    public ServiceSpecFluent.TemplateNested<A> editOrNewTemplate();
    public ServiceSpecFluent.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item);
    public A addToTraffic(int index,TrafficTarget item);
    public A setToTraffic(int index,TrafficTarget item);
    public A addToTraffic(TrafficTarget... items);
    public A addAllToTraffic(Collection<TrafficTarget> items);
    public A removeFromTraffic(TrafficTarget... items);
    public A removeAllFromTraffic(Collection<TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@java.lang.Deprecated public List<TrafficTarget> getTraffic();
    public List<TrafficTarget> buildTraffic();
    public TrafficTarget buildTraffic(int index);
    public TrafficTarget buildFirstTraffic();
    public TrafficTarget buildLastTraffic();
    public TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);
    public A withTraffic(List<TrafficTarget> traffic);
    public A withTraffic(TrafficTarget... traffic);
    public Boolean hasTraffic();
    public ServiceSpecFluent.TrafficNested<A> addNewTraffic();
    public ServiceSpecFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
    public ServiceSpecFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
    public ServiceSpecFluent.TrafficNested<A> editTraffic(int index);
    public ServiceSpecFluent.TrafficNested<A> editFirstTraffic();
    public ServiceSpecFluent.TrafficNested<A> editLastTraffic();
    public ServiceSpecFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<TrafficTargetBuilder> predicate);

    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RevisionTemplateSpecFluent<ServiceSpecFluent.TemplateNested<N>>{

        
    public N and();    public N endTemplate();
}
    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TrafficTargetFluent<ServiceSpecFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}


}

==> knative-model-5.3.0-sources.jar: io/fabric8/knative/serving/v1/ServiceSpecFluent.java <==
package io.fabric8.knative.serving.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.util.Collection;
import java.lang.Object;
import java.util.Map;

public interface ServiceSpecFluent<A extends ServiceSpecFluent<A>> extends Fluent<A> {


    
/**
 * This method has been deprecated, please use method buildTemplate instead.
 * @return The buildable object.
 */
@Deprecated public RevisionTemplateSpec getTemplate();
    public RevisionTemplateSpec buildTemplate();
    public A withTemplate(RevisionTemplateSpec template);
    public Boolean hasTemplate();
    public ServiceSpecFluent.TemplateNested<A> withNewTemplate();
    public ServiceSpecFluent.TemplateNested<A> withNewTemplateLike(RevisionTemplateSpec item);
    public ServiceSpecFluent.TemplateNested<A> editTemplate();
    public ServiceSpecFluent.TemplateNested<A> editOrNewTemplate();
    public ServiceSpecFluent.TemplateNested<A> editOrNewTemplateLike(RevisionTemplateSpec item);
    public A addToTraffic(int index,TrafficTarget item);
    public A setToTraffic(int index,TrafficTarget item);
    public A addToTraffic(TrafficTarget... items);
    public A addAllToTraffic(Collection<TrafficTarget> items);
    public A removeFromTraffic(TrafficTarget... items);
    public A removeAllFromTraffic(Collection<TrafficTarget> items);
    public A removeMatchingFromTraffic(Predicate<TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<TrafficTarget> getTraffic();
    public List<TrafficTarget> buildTraffic();
    public TrafficTarget buildTraffic(int index);
    public TrafficTarget buildFirstTraffic();
    public TrafficTarget buildLastTraffic();
    public TrafficTarget buildMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public A withTraffic(List<TrafficTarget> traffic);
    public A withTraffic(TrafficTarget... traffic);
    public Boolean hasTraffic();
    public ServiceSpecFluent.TrafficNested<A> addNewTraffic();
    public ServiceSpecFluent.TrafficNested<A> addNewTrafficLike(TrafficTarget item);
    public ServiceSpecFluent.TrafficNested<A> setNewTrafficLike(int index,TrafficTarget item);
    public ServiceSpecFluent.TrafficNested<A> editTraffic(int index);
    public ServiceSpecFluent.TrafficNested<A> editFirstTraffic();
    public ServiceSpecFluent.TrafficNested<A> editLastTraffic();
    public ServiceSpecFluent.TrafficNested<A> editMatchingTraffic(Predicate<TrafficTargetBuilder> predicate);
    public interface TemplateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RevisionTemplateSpecFluent<ServiceSpecFluent.TemplateNested<N>> {

            public N and();
            public N endTemplate();    }


    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,TrafficTargetFluent<ServiceSpecFluent.TrafficNested<N>> {

            public N and();
            public N endTraffic();    }


}
